Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(243)

Unified Diff: ui/views/view.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Full patch including mechanical changes Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/views/controls/webview/webview.cc ('k') | ui/views/widget/native_widget_mac_accessibility_unittest.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/views/view.h
diff --git a/ui/views/view.h b/ui/views/view.h
index 572d3a55f0487c33d11ef164b203bcb513cce133..48b904596fc8287892b13659f2599ed91cb2c472 100644
--- a/ui/views/view.h
+++ b/ui/views/view.h
@@ -53,7 +53,8 @@ class Transform;
}
namespace ui {
-struct AXViewState;
+struct AXActionData;
+struct AXNodeData;
class Compositor;
class InputMethod;
class Layer;
@@ -945,8 +946,12 @@ class VIEWS_EXPORT View : public ui::LayerDelegate,
// Accessibility -------------------------------------------------------------
- // Modifies |state| to reflect the current accessible state of this view.
- virtual void GetAccessibleState(ui::AXViewState* state) { }
+ // Modifies |node_data| to reflect the current accessible state of this view.
+ virtual void GetAccessibleNodeData(ui::AXNodeData* node_data) {}
sky 2016/11/03 20:10:14 While you're changing all this code is there a rea
dmazzoni 2016/11/03 22:27:37 I'm leaning against doing that because this matche
sky 2016/11/03 23:12:47 I didn't look everywhere, but in the couple of pla
+
+ // Handle a request from assistive technology to perform an action on this
+ // view.
+ virtual void HandleAccessibleAction(const ui::AXActionData& action_data) {}
sky 2016/11/03 20:10:14 Would this be easier for subclassing if it returne
dmazzoni 2016/11/03 22:27:37 Sure, done. I added a comment to clarify that the
// Returns an instance of the native accessibility interface for this view.
virtual gfx::NativeViewAccessible GetNativeViewAccessible();
« no previous file with comments | « ui/views/controls/webview/webview.cc ('k') | ui/views/widget/native_widget_mac_accessibility_unittest.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698